@@ -6,15 +6,17 @@
 
 package Lemonldap::NG::Manager::Build::Attributes;
 
-our $VERSION = '1.9.1';
+our $VERSION = '1.9.3';
 use strict;
 use Regexp::Common qw/URI/;
 
 my $perlExpr = sub {
     my ( $val, $conf ) = @_;
-    my $s = '';
-    my @cf =
-      qw(encode_base64 checkLogonHours date checkDate basic unicode2iso iso2unicode groupMatch);
+    my $s  = '';
+    my @cf = qw(
+      encode_base64 checkLogonHours date checkDate basic unicode2iso
+      iso2unicode groupMatch encrypt
+    );
     push @cf,
       defined $conf->{customFunctions}
       ? map { my $f = $_; $f =~ s/\w+:://g; ( $f, $_ ) }
@@ -24,7 +26,7 @@ my $perlExpr = sub {
         $s = "sub $f {1} $s";
     }
     eval "$s $val";
-    return $@ ? ( 0, "__badExpression__: $@" ) : (1);
+    return $@ ? ( 1, "__badExpression__: $@" ) : (1);
 };
 
 my $url = $RE{URI}{HTTP}{ -scheme => "https?" };
@@ -637,8 +639,8 @@ sub attributes {
             documentation => 'Captcha size',
         },
 
-        #captcha_data             => {
-        #captcha_output           => {
+        #captcha_data
+        #captcha_output
         captchaStorage => {
             type          => 'PerlModule',
             default       => 'Apache::Session::File',
@@ -756,6 +758,46 @@ sub attributes {
             documentation => 'OpenID Connect server rule',
         },
 
+        # GET issuer
+        issuerDBGetActivation => {
+            type          => 'bool',
+            default       => '0',
+            documentation => 'Get issuer activation',
+        },
+        issuerDBGetPath => {
+            type          => 'text',
+            default       => '^/get/',
+            documentation => 'Get issuer request path',
+        },
+        issuerDBGetRule => {
+            type          => 'boolOrExpr',
+            default       => 1,
+            documentation => 'Get issuer rule',
+        },
+        issuerDBGetParameters => {
+            type       => 'doubleHash',
+            default    => {},
+            keyTest    => qr/^$Regexp::Common::URI::RFC2396::hostname$/,
+            keyMsgFail => '__badHostname__',
+            test       => {
+                keyTest    => qr/^(?=[^\-])[\w\-]+(?<=[^-])$/,
+                keyMsgFail => '__badKeyName__',
+                test       => sub {
+                    my ( $val, $conf ) = @_;
+                    return 1
+                      if ( defined $conf->{macros}->{$val}
+                        or $val eq '_timezone' );
+                    foreach ( keys %$conf ) {
+                        return 1
+                          if ( $_ =~ /exportedvars$/i
+                            and defined $conf->{$_}->{$val} );
+                    }
+                    return ( 1, "__unknownAttrOrMacro__: $val" );
+                },
+            },
+            documentation => 'List of virtualHosts with their get parameters',
+        },
+
         # Password
         mailOnPasswordChange => {
             default       => 0,
@@ -813,8 +855,9 @@ sub attributes {
             documentation => 'URL of password reset page',
         },
         SMTPServer => {
-            type          => 'hostname',
-            default       => '',
+            type    => 'text',
+            default => '',
+            test    => qr/^(?:$Regexp::Common::URI::RFC2396::host(?::\d+)?)?$/,
             documentation => 'SMTP Server',
         },
         SMTPAuthUser => { type => 'text', },
@@ -921,7 +964,7 @@ sub attributes {
                     }
                     $s =~ s/\b(accept|deny|unprotect|skip)\b/1/g;
                     my @cf =
-                      qw(encode_base64 checkLogonHours date checkDate basic unicode2iso iso2unicode groupMatch);
+                      qw(encode_base64 checkLogonHours date checkDate basic unicode2iso iso2unicode groupMatch encrypt);
                     push @cf,
                       defined $conf->{customFunctions}
                       ? map { my $f = $_; $f =~ s/\w+:://g; ( $f, $_ ) }
@@ -931,7 +974,7 @@ sub attributes {
                         $s = "sub $f {1} $s";
                     }
                     eval $s;
-                    return $@ ? ( 0, "__badExpression__: $@" ) : (1);
+                    return $@ ? ( 1, "__badExpression__: $@" ) : (1);
                 },
                 msgFail => '__badExpression__',
             },
@@ -954,7 +997,7 @@ sub attributes {
                     my ( $val, $conf ) = @_;
                     my $s = $val;
                     my @cf =
-                      qw(encode_base64 checkLogonHours date checkDate basic unicode2iso iso2unicode groupMatch);
+                      qw(encode_base64 checkLogonHours date checkDate basic unicode2iso iso2unicode groupMatch encrypt);
                     push @cf,
                       defined $conf->{customFunctions}
                       ? map { my $f = $_; $f =~ s/\w+:://g; ( $f, $_ ) }
@@ -964,7 +1007,7 @@ sub attributes {
                         $s = "sub $f {1} $s";
                     }
                     eval $s;
-                    return $@ ? ( 0, "__badExpression__: $@" ) : (1);
+                    return $@ ? ( 1, "__badExpression__: $@" ) : (1);
                   }
             },
             documentation => 'Virtualhost headers',
@@ -1828,7 +1871,12 @@ m{^(?:ldapi://[^/]*/?|\w[\w\-\.]*(?::\d{1,5})?|ldap(?:s|\+tls)?://\w[\w\-\.]*(?:
             default       => 3,
             documentation => 'LDAP protocol version',
         },
-        ldapRaw => { type => 'text', },
+        ldapRaw                       => { type => 'text', },
+        ldapAllowResetExpiredPassword => {
+            default       => 0,
+            type          => 'bool',
+            documentation => 'Allow a user to reset his expired password',
+        },
 
         # SSL
         SSLAuthnLevel => {
