@@ -19,6 +19,8 @@ use feature 'state';
 
 extends 'Lemonldap::NG::Manager::Lib';
 
+our $VERSION = '1.9.3';
+
 #############################
 # I. INITIALIZATION METHODS #
 #############################
@@ -430,7 +432,10 @@ sub _oidcMetaDataNodes {
     my ( $id, $resp ) = ( 1, [] );
 
     # Return all exported attributes if asked
-    if ( $query =~ /^oidc${type}MetaDataExportedVars$/ ) {
+    if ( $query =~
+        /^(?:oidc${type}MetaDataExportedVars|oidcRPMetaDataOptionsExtraClaims)$/
+      )
+    {
         my $pk = eval { $self->getConfKey( $req, $query )->{$partner} } // {};
         return $self->sendError( $req, undef, 400 ) if ( $req->error );
         foreach my $h ( sort keys %$pk ) {
@@ -678,7 +683,7 @@ sub metadatas {
         my $id = -1;
         my ($ind) = map { $id++; $_ == $res->{cfgNum} ? ($id) : () } @a;
         if ($ind)         { $res->{prev} = $a[ $ind - 1 ]; }
-        if ( $ind < $#a ) { $res->{next} = $a[ $ind + 1 ]; }
+        if ( $ind and $ind < $#a ) { $res->{next} = $a[ $ind + 1 ]; }
         $self->userNotice( 'User '
               . $self->userId($req)
               . ' ask for configuration metadatas ('
@@ -731,6 +736,19 @@ sub getKey {
         }
         return $self->sendJSONresponse( $req, \@res );
     }
+    elsif ( $key =~ qr/^$doubleHashKeys$/o ) {
+        my @res;
+        if ( defined $value ) {
+            foreach my $host ( sort keys %$value ) {
+                my @tmp;
+                foreach my $k ( sort keys %{ $value->{$host} } ) {
+                    push @tmp, { k => $k, v => $value->{$host}->{$k} };
+                }
+                push @res, { k => $host, h => \@tmp };
+            }
+        }
+        return $self->sendJSONresponse( $req, { value => \@res } );
+    }
 
     # When scalar
     return $self->sendError( $req, "Key $key is not a hash", 400 )
