@@ -24,7 +24,7 @@ use Mouse;
 use Lemonldap::NG::Manager::Constants;
 use Lemonldap::NG::Manager::Attributes;
 
-our $VERSION = '1.9.3';
+our $VERSION = '1.9.4';
 
 # High debugging for developpers, set this to 1
 use constant HIGHDEBUG => 0;
@@ -121,9 +121,10 @@ sub scanTree {
 
     # Set cfgNum to ref cfgNum (will be changed when saving), set other
     # metadatas and set a value to the key if empty
-    $self->newConf->{cfgNum}    = $self->req->params('cfgNum');
-    $self->newConf->{cfgAuthor} = $self->req->userData->{_whatToTrace}
-      // "anonymous";
+    $self->newConf->{cfgNum} = $self->req->params('cfgNum');
+    $self->newConf->{cfgAuthor} =
+      $self->req->userData->{ $Lemonldap::NG::Handler::Main::tsv->{whatToTrace}
+          || '_whatToTrace' } // "anonymous";
     $self->newConf->{cfgAuthorIP} = $self->req->remote_ip;
     $self->newConf->{cfgDate}     = time;
     $self->newConf->{key} ||=
@@ -200,6 +201,12 @@ sub _scanNodes {
 
             # Check hostname/partner name changes (id points to the old name)
             $newNames{$host} = $leaf->{title};
+            if ( $newNames{$host} ne $host and $host !~ /^new__/ ) {
+                hdebug("  $host becomes $newNames{$host}");
+                $self->confChanged(1);
+                push @{ $self->changes },
+                  { key => $base, old => $host, new => $newNames{$host} };
+            }
 
             $self->_scanNodes($subNodes);
             next;
@@ -209,7 +216,8 @@ sub _scanNodes {
         elsif ( $leaf->{id} =~
             /^($specialNodeKeys)\/([^\/]+)\/([^\/]+)(?:\/(.*))?$/io )
         {
-            my ( $base, $key, $target, $h ) = ( $1, $newNames{$2}, $3, $4 );
+            my ( $base, $key, $oldName, $target, $h ) =
+              ( $1, $newNames{$2}, $2, $3, $4 );
             hdebug(
                 "Special node chield subnode detected $leaf->{id}",
                 "  base $base, key $key, target $target, h "
@@ -223,7 +231,7 @@ sub _scanNodes {
                     if ( $leaf->{cnodes} ) {
                         hdebug('    unopened subnode');
                         $self->newConf->{$target}->{$key} =
-                          $self->refConf->{$target}->{$key} // {};
+                          $self->refConf->{$target}->{$oldName} // {};
                     }
 
                     elsif ($h) {
@@ -281,7 +289,8 @@ sub _scanNodes {
                     }
                 }
                 elsif ( $target =~ /^$virtualHostKeys$/o ) {
-                    $self->set( 'vhostOptions', $key, $target, $leaf->{data} );
+                    $self->set( 'vhostOptions', [ $oldName, $key ],
+                        $target, $leaf->{data} );
                 }
                 else {
                     push @{ $self->errors },
@@ -303,7 +312,7 @@ sub _scanNodes {
                     if ( $leaf->{cnodes} ) {
                         hdebug("  $target: unopened node");
                         $self->newConf->{$target}->{$key} =
-                          $self->refConf->{$target}->{$key} // {};
+                          $self->refConf->{$target}->{$oldName} // {};
                     }
                     elsif ($h) {
                         hdebug("  $target: opened node");
@@ -317,7 +326,8 @@ sub _scanNodes {
                 }
                 elsif ( $target =~ /^saml(?:S|ID)PMetaDataXML$/ ) {
                     hdebug("  $target");
-                    $self->set( $target, $key, $target, $leaf->{data} );
+                    $self->set( $target, [ $oldName, $key ],
+                        $target, $leaf->{data} );
                 }
                 elsif ( $target =~ /^saml(?:ID|S)PMetaDataOptions/ ) {
                     my $optKey = $&;
@@ -326,7 +336,10 @@ sub _scanNodes {
                         /^(?:$samlIDPMetaDataNodeKeys|$samlSPMetaDataNodeKeys)/o
                       )
                     {
-                        $self->set( $optKey, $key, $target, $leaf->{data} );
+                        $self->set(
+                            $optKey, [ $oldName, $key ],
+                            $target, $leaf->{data}
+                        );
                     }
                     else {
                         push @{ $self->errors },
@@ -359,7 +372,7 @@ sub _scanNodes {
                     if ( $leaf->{cnodes} ) {
                         hdebug('    unopened');
                         $self->newConf->{$target}->{$key} =
-                          $self->refConf->{$target}->{$key} // {};
+                          $self->refConf->{$target}->{$oldName} // {};
                     }
                     elsif ($h) {
                         hdebug('    opened');
@@ -378,7 +391,7 @@ sub _scanNodes {
                         if ( $leaf->{cnodes} ) {
                             hdebug('    unopened');
                             $self->newConf->{$target}->{$key} =
-                              $self->refConf->{$target}->{$key} // {};
+                              $self->refConf->{$target}->{$oldName} // {};
                         }
                         elsif ($h) {
                             hdebug('    opened');
@@ -394,7 +407,10 @@ sub _scanNodes {
                         /^(?:$oidcOPMetaDataNodeKeys|$oidcRPMetaDataNodeKeys)/o
                       )
                     {
-                        $self->set( $optKey, $key, $target, $leaf->{data} );
+                        $self->set(
+                            $optKey, [ $oldName, $key ],
+                            $target, $leaf->{data}
+                        );
                     }
                     else {
                         push @{ $self->errors },
@@ -696,7 +712,7 @@ sub _scanNodes {
             $self->newConf->{$name} = {};
             unless ( defined $leaf->{data} ) {
                 hdebug('  unopened');
-                $self->newConf->{$name} = $self->refConf->{$name};
+                $self->newConf->{$name} = $self->refConf->{$name} || {};
                 next;
             }
             foreach my $getHost ( @{ $leaf->{data} } ) {
@@ -813,8 +829,9 @@ sub set {
         my $tmp = shift;
         push @path, $tmp;
         foreach my $i ( 0, 1 ) {
-            $confs[$i]->{$tmp} //= {};
-            $confs[$i] = $confs[$i]->{$tmp};
+            my $v = ref($tmp) ? $tmp->[$i] : $tmp;
+            $confs[$i]->{$v} //= {};
+            $confs[$i] = $confs[$i]->{$v};
         }
     }
     my $target = shift;
@@ -995,6 +1012,7 @@ sub _execTest {
     # Recursive test (for locationRules,...)
     else {
         my $res = 1;
+        return $res unless ( ref($value) eq 'HASH' );
         foreach my $k ( keys %$value ) {
             $res = 0
               unless (
