@@ -95,18 +95,15 @@ sub sessions {
     my @fields =
       ( '_httpSessionType', $self->{ipField}, $tsv->{whatToTrace} );
     if ( my $groupBy = $params->{groupBy} ) {
-        $groupBy = $1
-          if ( $groupBy =~ /^substr\((\w+)(?:,\d+(?:,\d+)?)?\)$/ );
-        if ( $groupBy =~ /^net4\((\w+),\d\)$/ ) {
-            push @fields, $1;
-        }
-        else {
-            push @fields, $groupBy;
-        }
+        $groupBy =~ s/^substr\((\w+)(?:,\d+(?:,\d+)?)?\)$/$1/
+          or $groupBy =~ s/^net4\((\w+),\d\)$/$1/;
+        $groupBy =~ s/^_whatToTrace$/$tsv->{whatToTrace}/o
+          or push @fields, $groupBy;
     }
     elsif ( my $order = $params->{orderBy} ) {
-        $order =~ s/^net4\((\w+)\)$/$1/;
-        push @fields, split( /, /, $order );
+        $order =~ s/\bnet4\((\w+)\)$/$1/;
+        $order =~ s/\b_whatToTrace\b/$tsv->{whatToTrace}/o
+          or push @fields, split( /, /, $order );
     }
     else {
         push @fields, '_utime';
@@ -118,9 +115,11 @@ sub sessions {
     $moduleOptions->{backend} = $mod->{module};
     if (
         my %filters = map {
+            my $s = $_;
+            s/\b_whatToTrace\b/$tsv->{whatToTrace}/o;
             /^(?:(?:group|order)By|doubleIp)$/
               ? ()
-              : ( $_ => $params->{$_} );
+              : ( $_ => $params->{$s} );
         } keys %$params
       )
     {
@@ -215,6 +214,7 @@ sub sessions {
     #   { uid => 'foo.bar', count => 3 }
     elsif ( my $group = $req->params('groupBy') ) {
         my $r;
+        $group =~ s/\b_whatToTrace\b/$tsv->{whatToTrace}/o;
 
         # Substrings
         if ( $group =~ /^substr\((\w+)(?:,(\d+)(?:,(\d+))?)?\)$/ ) {
@@ -243,9 +243,14 @@ sub sessions {
 
         # Simple field groupBy query
         elsif ( $group =~ /^\w+$/ ) {
-            foreach my $k ( keys %$res ) {
-                $r->{ $res->{$k}->{$group} }++;
-            }
+            eval {
+                foreach my $k ( keys %$res ) {
+                    $r->{ $res->{$k}->{$group} }++;
+                }
+            };
+            return $self->sendError( $req,
+                "Use of an unexistent attribute $group to group sessions", 400 )
+              if ($@);
         }
         else {
             return $self->sendError( $req, 'Syntax error in groupBy', 400 );
@@ -272,6 +277,7 @@ sub sessions {
             $tmp
         } keys %$res;
         while ( my $f = pop @fields ) {
+            $f =~ s/^_whatToTrace$/$tsv->{whatToTrace}/o;
             if ( $f =~ s/^net4\((\w+)\)$/$1/ ) {
                 @r = sort {
                     my @a = split /\./, $a->{$f};
